SEPA Credit Transfer (CBI) request generator
--------------------------------------------

The ``sepacbi`` module generates SEPA Credit Transfer requests in the XML format standardized by CBI and accepted by Italian banks.

The module does not currently support other requests (such as Direct Debit), nor does it support status changes.

The development of this module is funded by `Linkspirit`_.

.. _Linkspirit: http://www.linkspirit.it/
